/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.truffle.r.nodes.builtin.base;

import static com.oracle.truffle.r.runtime.RBuiltinKind.*;

import com.oracle.truffle.api.dsl.*;
import com.oracle.truffle.api.utilities.*;
import com.oracle.truffle.r.nodes.*;
import com.oracle.truffle.r.nodes.access.*;
import com.oracle.truffle.r.nodes.builtin.*;
import com.oracle.truffle.r.runtime.*;
import com.oracle.truffle.r.runtime.data.*;

@RBuiltin(name = ".Primitive", kind = PRIMITIVE, parameterNames = "name")
public abstract class Primitive extends RBuiltinNode {
    protected final BranchProfile errorProfile = BranchProfile.create();

    @Override
    public RNode[] getParameterValues() {
        return new RNode[]{ConstantNode.create(RMissing.instance)};
    }

    @Specialization
    protected RFunction primitive(String name) {
        RFunction function = RContext.getEngine().lookupBuiltin(name);
        if (function == null || function.getRBuiltin() != null && function.getRBuiltin().kind() != RBuiltinKind.PRIMITIVE) {
            errorProfile.enter();
            throw RError.error(getEncapsulatingSourceSection(), RError.Message.NO_SUCH_PRIMITIVE, name);
        }

        // .Primitive function is validated
        return function;
    }

    @Fallback
    protected RFunction primitive(@SuppressWarnings("unused") Object name) {
        throw RError.error(getEncapsulatingSourceSection(), RError.Message.STRING_ARGUMENT_REQUIRED);
    }
}
